worker

package
v0.0.0-...-e303333 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 29, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type WorkerApplication

type WorkerApplication struct {
	*app.Application
	// contains filtered or unexported fields
}

WorkerApplication 工作者应用

func (*WorkerApplication) Run

func (app *WorkerApplication) Run(ctx ...context.Context)

Run 运行应用

type WorkerApplicationBuilder

type WorkerApplicationBuilder struct {
	*app.ApplicationBuilder
	// contains filtered or unexported fields
}

WorkerApplicationBuilder is a builder for creating a WorkerApplication.

func NewWorkerAppBuilder

func NewWorkerAppBuilder() *WorkerApplicationBuilder

NewWorkerAppBuilder creates a new WorkerApplicationBuilder.

func (*WorkerApplicationBuilder) Build

Build creates a new WorkerApplication.

func (*WorkerApplicationBuilder) OnStart

OnStart sets the function to be called when the application starts.

func (*WorkerApplicationBuilder) OnStop

OnStop sets the function to be called when the application stops.

Jump to