Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WorkerApplication ¶
type WorkerApplication struct {
*app.Application
// contains filtered or unexported fields
}
WorkerApplication 工作者应用
type WorkerApplicationBuilder ¶
type WorkerApplicationBuilder struct {
*app.ApplicationBuilder
// contains filtered or unexported fields
}
WorkerApplicationBuilder is a builder for creating a WorkerApplication.
func NewWorkerAppBuilder ¶
func NewWorkerAppBuilder() *WorkerApplicationBuilder
NewWorkerAppBuilder creates a new WorkerApplicationBuilder.
func (*WorkerApplicationBuilder) Build ¶
func (b *WorkerApplicationBuilder) Build() *WorkerApplication
Build creates a new WorkerApplication.
func (*WorkerApplicationBuilder) OnStart ¶
func (b *WorkerApplicationBuilder) OnStart(fn func() error) *WorkerApplicationBuilder
OnStart sets the function to be called when the application starts.
func (*WorkerApplicationBuilder) OnStop ¶
func (b *WorkerApplicationBuilder) OnStop(fn func() error) *WorkerApplicationBuilder
OnStop sets the function to be called when the application stops.
Click to show internal directories.
Click to hide internal directories.